
# Slot: id


A unique identifier for a thing

URI: [nwb_schema_language:id](https://w3id.org/p2p_ld/nwb-schema-language/id)


## Domain and Range

None &#8594;  <sub>1..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [NamedThing](NamedThing.md)
 * [Namespaces](Namespaces.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:identifier |

